/* BASSWMA 1.6 C/C++ header file, copyright (c) 2002 Ian Luck.
   Requires BASS 1.6 - available from www.un4seen.com

   See the BASSWMA.CHM file for more complete documentation */

#ifndef BASSWMA_H
#define BASSWMA_H

#include "bass.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef BASSWMADEF
#define BASSWMADEF(f) WINAPI f
#endif

typedef DWORD HWMENCODE;		// WMA encoding handle

// Additional error codes returned by BASS_WMA_GetErrorCode
#define BASS_ERROR_WMA_LICENSE	1000	// the file is protected

// Additional flags for use with BASS_WMA_EncodeOpenFile/Network
#define BASS_WMA_ENCODE_TAGS	0x10000 // set tags in the WMA encoding


DWORD BASSWMADEF(BASS_WMA_ErrorGetCode)();
/* Get the BASS_ERROR_xxx error code. Use this function to get the
reason for an error. */

HSTREAM BASSWMADEF(BASS_WMA_StreamCreateFile)(BOOL mem, void *file, DWORD offset, DWORD length, DWORD flags);
/* Create a sample stream from a WMA file (or URL).
mem    : TRUE = Stream file from memory
file   : Filename (mem=FALSE) or memory location (mem=TRUE)
offset : ignored (set to 0)
length : Data length (only used if mem=TRUE)
flags  : Flags (BASS_SAMPLE_LOOP/3D/FX & BASS_STREAM_DECODE/AUTOFREE)
RETURN : The created stream's handle (NULL=error) */

void BASSWMADEF(BASS_WMA_StreamFree)(HSTREAM handle);
/* Free a WMA stream's resources.
handle : Stream handle */

QWORD BASSWMADEF(BASS_WMA_StreamGetLength)(HSTREAM handle);
/* Retrieve the playback length (in bytes) of a WMA stream.
handle : Stream handle 
RETURN : The length (-1=error) */

char *BASSWMADEF(BASS_WMA_StreamGetTags)(HSTREAM handle, DWORD tags);
/* Retrieve the WMA tags, if available.
handle : Stream handle
tags   : ignored
RETURN : Pointer to the tags (NULL=error) */

BOOL BASSWMADEF(BASS_WMA_StreamPlay)(HSTREAM handle, BOOL flush, DWORD flags);
/* Play a WMA stream.
handle : Handle of stream to play
flush  : TRUE=restart from the beginning.
flags  : BASS_SAMPLE_LOOP flag */

BOOL BASSWMADEF(BASS_WMA_ChannelSetPosition)(DWORD handle, QWORD pos);
/* Set the current playback position of a WMA channel.
handle : Channel handle
pos    : the position (in bytes) */

QWORD BASSWMADEF(BASS_WMA_ChannelGetPosition)(DWORD handle);
/* Get the current playback position of a WMA channel.
handle : Channel handle
RETURN : the position in bytes (-1=error) */

HSYNC BASSWMADEF(BASS_WMA_ChannelSetSync)(DWORD handle, DWORD type, QWORD param, SYNCPROC *proc, DWORD user);
/* Setup a sync on a WMA channel. Multiple syncs may be used per channel.
handle : Channel handle
type   : Sync type (BASS_SYNC_xxx type & flags)
param  : Sync parameters (see the BASS_SYNC_xxx type description)
proc   : User defined callback function
user   : The 'user' value passed to the callback function
RETURN : Sync handle (NULL=error) */

BOOL BASSWMADEF(BASS_WMA_ChannelRemoveSync)(DWORD handle, HSYNC sync);
/* Remove a sync from a WMA channel
handle : Channel handle
sync   : Handle of sync to remove */

void *BASSWMADEF(BASS_WMA_GetIWMReader)(HSTREAM handle);
/* Retrieve the IWMReader interface of a WMA stream. This allows direct
access to the WMFSDK functions.
handle : Channel handle
RETURN : Pointer to the IWMReader object interface (NULL=error) */


DWORD *BASSWMADEF(BASS_WMA_EncodeGetRates)(DWORD freq, DWORD flags);
/* Retrieve a list of the encoding bitrates available for a
specified input sample format.
freq   : Sampling rate
flags  : BASS_SAMPLE_MONO flag
RETURN : Pointer to an array of bitrates, terminated by a 0 (NULL=error) */ 

HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenFile)(DWORD freq, DWORD flags, DWORD bitrate, char *file);
/* Initialize WMA encoding to a file.
freq   : Sampling rate
flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
bitrate: Encoding bitrate
file   : Filename
RETURN : The created encoder's handle (0=error) */

HWMENCODE BASSWMADEF(BASS_WMA_EncodeOpenNetwork)(DWORD freq, DWORD flags, DWORD bitrate, DWORD port, DWORD clients);
/* Initialize WMA encoding to the network.
freq   : Sampling rate
flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
bitrate: Encoding bitrate
port   : Port number for clients to conenct to (0=let system choose)
clients: Maximum number of clients that can connect
RETURN : The created encoder's handle (0=error) */

DWORD BASSWMADEF(BASS_WMA_EncodeGetPort)(HWMENCODE handle);
/* Retrieve the port for clients to connect to a network encoder.
handle : Encoder handle
RETURN : The port number for clients to connect to (0=error) */

DWORD BASSWMADEF(BASS_WMA_EncodeGetClients)(HWMENCODE handle);
/* Retrieve the number of clients connected.
handle : Encoder handle
RETURN : The number of clients (-1=error) */

BOOL BASSWMADEF(BASS_WMA_EncodeSetTag)(HWMENCODE handle, char *tag, char *text);
/* Set a tag. Requires that the BASS_WMA_ENCODE_TAGS flag was used in
the BASS_WMA_EncodeOpenFile/Network call. 
handle : Encoder handle
tag    : The tag (NULL=no more tags)
text   : The tag's text */

BOOL BASSWMADEF(BASS_WMA_EncodeWrite)(HWMENCODE handle, void *buffer, DWORD length);
/* Encode sample data and write it to the file or network.
handle : Encoder handle
buffer : Buffer containing the sample data
length : Number of bytes in the buffer */

void BASSWMADEF(BASS_WMA_EncodeClose)(HWMENCODE handle);
/* Finish encoding and close the file or network port.
handle : Encoder handle */

#ifdef __cplusplus
}
#endif

#endif
