/* WMA version of the BASS Simple Console Test, copyright (c) 1999-2002 Ian Luck.
=================================================================================
Imports: bass.lib, basswma.lib, kernel32.lib, winmm.lib
*/

#include <windows.h>
#include <mmsystem.h>
#include <stdio.h>
#include <conio.h>
#include "bass.h"
#include "basswma.h"

/* display error messages */
void Error(char *text) 
{
	printf("Error(%d,%d): %s\n",BASS_ErrorGetCode(),BASS_WMA_ErrorGetCode(),text);
	BASS_Free();
	ExitProcess(0);
}

DWORD starttime;

/* looping synchronizer, resets the clock */
void CALLBACK LoopSync(HSYNC handle, DWORD channel, DWORD data, DWORD user)
{
	starttime=timeGetTime();
}

void main(int argc, char **argv)
{
	HMUSIC mod;
	HSTREAM str;
	DWORD act,time,level;
	QWORD pos;
	int a,freq;

	printf("Simple console mode BASS example : MOD/MPx/OGG/WAV/WMA player\n"
			"-------------------------------------------------------------\n");

	/* check that BASS 1.6 was loaded */
	if (BASS_GetVersion()!=MAKELONG(1,6)) {
		printf("BASS version 1.6 was not loaded\n");
		return;
	}

	if (argc!=2) {
		printf("\tusage: contest <file>\n");
		return;
	}

	/* setup output - default device, 44100hz, stereo, 16 bits */
	if (!BASS_Init(-1,44100,0,0))
		Error("Can't initialize device");

	/* try streaming the file/url */
	if ((str=BASS_StreamCreateFile(FALSE,argv[1],0,0,0))
		|| (str=BASS_StreamCreateURL(argv[1],0,BASS_STREAM_RESTRATE,0))
		|| (str=BASS_WMA_StreamCreateFile(FALSE,argv[1],0,0,0))) {
		/* set a synchronizer for when the stream reaches the end */
		if (BASS_WMA_GetIWMReader(str)) { // it's a WMA channel
			BASS_WMA_ChannelSetSync(str,BASS_SYNC_END,0,&LoopSync,0);
			pos=BASS_WMA_StreamGetLength(str);
		} else {
			BASS_ChannelSetSync(str,BASS_SYNC_END,0,&LoopSync,0);
			pos=BASS_StreamGetLength(str);
		}
		if (BASS_StreamGetFilePosition(str,1)!=-1) {
			/* streaming from the internet */
			if (pos)
				printf("streaming internet file [%I64d bytes]",pos);
			else
				printf("streaming internet file");
		} else
			printf("streaming file [%I64d bytes]",pos);
	} else {
		/* try loading the MOD (with looping, sensitive ramping, and calculate the duration) */
		if (!(mod=BASS_MusicLoad(FALSE,argv[1],0,0,BASS_MUSIC_LOOP|BASS_MUSIC_RAMPS|BASS_MUSIC_CALCLEN)))
			/* not a MOD either */
			Error("Can't play the file");
		/* set a synchronizer for when the MOD reaches the end */
		BASS_ChannelSetSync(mod,BASS_SYNC_END,0,&LoopSync,0);
		/* count channels */
		for (a=0;BASS_MusicGetChannelVol(mod,a)!=-1;a++);
		printf("playing MOD music \"%s\" [%d chans, %d orders]",BASS_MusicGetName(mod),a,BASS_MusicGetLength(mod,FALSE));
		pos=BASS_MusicGetLength(mod,TRUE);
	}

	/* display the time length */
	if (pos) {
		time=(DWORD)BASS_ChannelBytes2Seconds(str?str:mod,pos);
		printf(" %d:%02d\n",time/60,time%60);
	} else /* no time length available */
		printf("\n");

	BASS_Start();

	if (str) {
		if (!BASS_WMA_StreamPlay(str,0,BASS_SAMPLE_LOOP))
			BASS_StreamPlay(str,0,BASS_SAMPLE_LOOP);
	} else
		BASS_MusicPlay(mod);
	starttime=timeGetTime();

	/* NOTE: some compilers don't support _kbhit */
	while (!_kbhit() && (act=BASS_ChannelIsActive(str?str:mod))) {
		/* display some stuff and wait a bit */
		time=timeGetTime()-starttime;
		level=BASS_ChannelGetLevel(str?str:mod);
		pos=BASS_WMA_ChannelGetPosition(str);
		if (pos==-1) // not a WMA channel
			pos=BASS_ChannelGetPosition(str?str:mod);
		if (str)
			printf("pos %09I64d - time %d:%02d - L ",pos,time/60000,(time/1000)%60);
		else
			printf("pos %03d:%03d - time %d:%02d - L ",LOWORD(pos),HIWORD(pos),time/60000,(time/1000)%60);
		if (act==2) {
			/* internet file stream playback has stalled */
			printf("-- buffering : %05d --",
				BASS_StreamGetFilePosition(str,1)-BASS_StreamGetFilePosition(str,0));
		} else {
			for (a=93;a;a=a*2/3) putchar(LOWORD(level)>=a?'*':'-');
			putchar(' ');
			for (a=1;a<128;a+=a-(a>>1)) putchar(HIWORD(level)>=a?'*':'-');
		}
		printf(" R - cpu %.1f%%  \r",BASS_GetCPU());
		Sleep(50);
	}
	printf("                                                                         \r");

	/* get the frequency... and wind it down */
	BASS_ChannelGetAttributes(str?str:mod,&freq,NULL,NULL);
	level=freq/40;
	for (;freq>2000;freq-=level) {
		BASS_ChannelSetAttributes(str?str:mod,freq,-1,-101);
		Sleep(5);
	}

	/* fade-out to avoid a "click" */
	for (a=100;a>=0;a-=5) {
		BASS_SetVolume(a);
		Sleep(1);
	}

	BASS_Free();
}
