{
  BASSWMA 1.6 Delphi API, copyright (c) 2002 Ian Luck.
  Requires BASS 1.6 - available from www.un4seen.com

  See the BASSWMA.CHM file for more complete documentation
}

Unit BASSWMA;

interface

uses windows, bass;

const
  // Additional error codes returned by BASS_WMA_GetErrorCode
  BASS_ERROR_WMA_LICENSE     = 1000;    // the file is protected

  // Additional flags for use with BASS_WMA_EncodeOpenFile/Network
  BASS_WMA_ENCODE_TAGS       = $10000; // set tags in the WMA encoding


type
  DWORD = cardinal;
  BOOL = LongBool;
  QWORD = int64;
  HSTREAM = DWORD;
  HSYNC = DWORD;
  HWMENCODE = DWORD;		// WMA encoding handle


  SYNCPROC = procedure(handle:HSYNC; channel,data,user:DWORD); stdcall;
  {
    Sync callback function. NOTE: a sync callback function should be very
    quick (eg. just posting a message) as other syncs cannot be processed
    until it has finished. If the sync is a "mixtime" sync, then other streams
    and MOD musics can not be mixed until it's finished either.
    handle : The sync that has occured
    channel: Channel that the sync occured in
    data   : Additional data associated with the sync's occurance
    user   : The 'user' parameter given when calling BASS_WMA_ChannelSetSync
  }


Function BASS_WMA_ErrorGetCode:DWORD; stdcall; external 'basswma.dll' name 'BASS_WMA_ErrorGetCode';
{
  Get the BASS_ERROR_xxx error code. Use this function to
  get the reason for an error.
}
Function BASS_WMA_StreamCreateFile(mem:BOOL; fl:pointer; offset,length,flags:DWORD): HSTREAM; stdcall; external 'basswma.dll' name 'BASS_WMA_StreamCreateFile';
{
  Create a sample stream from a WMA file (or URL).
  mem    : TRUE = Stream file from memory
  fl     : Filename (mem=FALSE) or memory location (mem=TRUE)
  offset : ignored (set to 0)
  length : Data length (only used if mem=TRUE)
  flags  : Flags (BASS_SAMPLE_LOOP/BASS_SAMPLE_3D/BASS_SAMPLE_FX/BASS_STREAM_DECODE)
  RETURN : The created stream's handle (NULL=error)
}
Procedure BASS_WMA_StreamFree(handle: HSTREAM); stdcall; external 'basswma.dll' name 'BASS_WMA_StreamFree';
{
  Free a WMA stream's resources.
  stream : Stream handle
}
Function BASS_WMA_StreamGetLength(handle: HSTREAM):QWORD; stdcall; external 'basswma.dll' name 'BASS_WMA_StreamGetLength';
{
  Retrieve the playback length (in bytes) of a WMA stream.
  handle : Stream handle 
  RETURN : The length ($ffffffff=error)
}
Function BASS_WMA_StreamGetTags(handle: HSTREAM; tags:dword): PCHAR; stdcall; external 'basswma.dll' name 'BASS_WMA_StreamGetTags';
{
  Retrieve the WMA tags, if available.
  handle : Stream handle
  tags   : ignored
  RETURN : Pointer to the tags (NULL=error)
}
Function BASS_WMA_StreamPlay(handle:HSTREAM; flush:BOOL; flags:DWORD):BOOL; stdcall; external 'basswma.dll' name 'BASS_WMA_StreamPlay';
{
  Play a WMA stream.
  handle : Handle of stream to play
  flush  : TRUE=restart from the beginning.
  flags  : BASS_SAMPLE_LOOP flag
}
Function BASS_WMA_ChannelSetPosition(handle:DWORD; pos:QWORD):BOOL; stdcall; external 'basswma.dll' name 'BASS_WMA_ChannelSetPosition';
{
  Set the current playback position of a WMA stream.
  handle : Channel handle
  pos    : the position (in bytes)
}
Function BASS_WMA_ChannelGetPosition(handle:DWORD):QWORD; stdcall; external 'basswma.dll' name 'BASS_WMA_ChannelGetPosition';
{
  Get the current playback position of a WMA stream.
  handle : Channel handle
  RETURN : the position in bytes ($ffffffff=error)
}
function BASS_WMA_ChannelSetSync(handle,atype:DWORD; param:QWORD; proc:SYNCPROC; user:DWORD): HSYNC; stdcall; external 'basswma.dll' name 'BASS_WMA_ChannelSetSync';
{
  Setup a sync on a WMA channel. Multiple syncs may be used per channel.
  handle : Channel handle
  atype  : Sync type (BASS_SYNC_xxx type & flags)
  param  : Sync parameters (see the BASS_SYNC_xxx type description)
  proc   : User defined callback function
  user   : The 'user' value passed to the callback function
  RETURN : Sync handle (NULL=error)
}
function BASS_WMA_ChannelRemoveSync(handle:DWORD; sync:HSYNC): BOOL; stdcall; external 'basswma.dll' name 'BASS_WMA_ChannelRemoveSync';
{
  Remove a sync from a WMA channel
  handle : Channel handle
  sync   : Handle of sync to remove
}
Function BASS_WMA_GetIWMReader(handle:HSTREAM): Pointer; stdcall; external 'basswma.dll' name 'BASS_WMA_GetIWMReader';
{
  Retrieve the IWMReader interface of a WMA stream. This allows direct
  access to the WMFSDK functions.
  handle : Channel handle
  RETURN : Pointer to the IWMReader object interface (NULL=error)
}

Function BASS_WMA_EncodeGetRates(freq,flags:DWORD): Pointer; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeGetRates';
{
  Retrieve a list of the encoding bitrates available for a
  specified input sample format.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO flag
  RETURN : Pointer to an array of bitrates, terminated by a 0 (NULL=error)
}
Function BASS_WMA_EncodeOpenFile(freq,flags,bitrate:DWORD; fname:PChar): HWMENCODE; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeOpenFile';
{
  Initialize WMA encoding to a file.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
  bitrate: Encoding bitrate
  fname  : Filename
  RETURN : The created encoder's handle (0=error)
}
Function BASS_WMA_EncodeOpenNetwork(freq,flags,bitrate,port,clients:DWORD): HWMENCODE; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeOpenNetwork';
{
  Initialize WMA encoding to the network.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
  bitrate: Encoding bitrate
  port   : Port number for clients to conenct to (0=let system choose)
  clients: Maximum number of clients that can connect
  RETURN : The created encoder's handle (0=error)
}
Function BASS_WMA_EncodeGetPort(handle:HWMENCODE): DWORD; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeGetPort';
{
  Retrieve the port for clients to connect to a network encoder.
  handle : Encoder handle
  RETURN : The port number for clients to connect to (0=error)
}
Function BASS_WMA_EncodeGetClients(handle:HWMENCODE): DWORD; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeGetClients';
{
  Retrieve the number of clients connected.
  handle : Encoder handle
  RETURN : The number of clients (-1=error)
}
Function BASS_WMA_EncodeSetTag(handle:HWMENCODE; tag,text:PChar): BOOL; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeSetTag';
{
  Set a tag. Requires that the BASS_WMA_ENCODE_TAGS flag was used in
  the BASS_WMA_EncodeOpenFile/Network call. 
  handle : Encoder handle
  tag    : The tag (NULL=no more tags)
  text   : The tag's text
}
Function BASS_WMA_EncodeWrite(handle:HWMENCODE; buffer:Pointer; length:DWORD): BOOL; stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeWrite';
{
  Encode sample data and write it to the file or network.
  handle : Encoder handle
  buffer : Buffer containing the sample data
  length : Number of bytes in the buffer
}
Procedure BASS_WMA_EncodeClose(handle:HWMENCODE); stdcall; external 'basswma.dll' name 'BASS_WMA_EncodeClose';
{
  Finish encoding and close the file or network port.
  handle : Encoder handle
}

implementation

end.
