(* BASSWMA 1.6 C/C++ header file, copyright (c) 2002 Ian Luck.
   Please report bugs/suggestions/etc... to bass@un4seen.com
   TMT Pascal Version by Vadim Bodrov, TMT Development Corporation

   Requires BASS 1.6 - available from www.un4seen.com
   
   See the BASSWMA.CHM file for more complete documentation *)

unit BassWMA;

{$oa+}

interface

{$ifndef __MULTITARGET__}
  This unit can be compiled with TMT Pascal Multi-target only
{$endif}

{$ifndef __WIN32__}
  Invalid compilation target
{$endif}

uses
  Windows, Bass;

const
  // Additional error codes returned by BASS_WMA_GetErrorCode
  BASS_ERROR_WMA_LICENSE     = 1000;    // the file is protected

  // Additional flags for use with BASS_WMA_EncodeOpenFile/Network
  BASS_WMA_ENCODE_TAGS       = $10000;  // set tags in the WMA encoding

type
  HWMENCODE = DWORD;		// WMA encoding handle


function BASS_WMA_ErrorGetCode conv arg_stdcall: DWORD; external 'basswma.dll';
(* Get the BASS_ERROR_xxx error code. Use this function to get the
reason for an error. *)

function BASS_WMA_StreamCreateFile conv arg_stdcall (mem: BOOL; fname: Pointer; offset, length, flags: DWORD): HSTREAM; external 'basswma.dll';
(* Create a sample stream from a WMA file (or URL).
mem    : TRUE = Stream file from memory
fname  : Filename (mem=FALSE) or memory location (mem=TRUE)
offset : ignored (set to 0)
length : Data length (only used if mem=TRUE)
flags  : Flags (BASS_SAMPLE_LOOP/BASS_SAMPLE_3D/BASS_SAMPLE_FX/BASS_STREAM_DECODE)
RETURN : The created stream's handle (NULL=error) *)

procedure BASS_WMA_StreamFree conv arg_stdcall (handle: HSTREAM); external 'basswma.dll';
(* Free a WMA stream's resources.
handle : Stream handle *)

function BASS_WMA_StreamGetLength conv arg_stdcall (handle: HSTREAM): QWORD; external 'basswma.dll';
(* Retrieve the playback length (in bytes) of a WMA stream.
handle : Stream handle
RETURN : The length (0xffffffff=error) *)

function BASS_WMA_StreamGetTags conv arg_stdcall (handle: HSTREAM; tags: DWORD): PChar; external 'basswma.dll';
(* Retrieve the WMA tags, if available.
handle : Stream handle
tags   : ignored
RETURN : Pointer to the tags (NULL=error) *)

function BASS_WMA_StreamPlay conv arg_stdcall (handle: HSTREAM; flush: BOOL; flags: DWORD): BOOL; external 'basswma.dll';
(* Play a WMA stream.
handle : Handle of stream to play
flush  : TRUE=restart from the beginning.
flags  : BASS_SAMPLE_LOOP flag *)

function BASS_WMA_ChannelSetPosition conv arg_stdcall (handle:DWORD; pos:QWORD): BOOL; external 'basswma.dll';
(* Set the current playback position of a WMA stream.
handle : Channel handle
pos    : the position (in bytes) *)

function BASS_WMA_ChannelGetPosition conv arg_stdcall (handle: DWORD): QWORD; external 'basswma.dll';
(* Get the current playback position of a WMA stream.
handle : Channel handle
RETURN : the position in bytes (0xffffffff=error) *)

function BASS_WMA_ChannelSetSync conv arg_stdcall (handle,atype:DWORD; param:QWORD; proc:SYNCPROC; user:DWORD): HSYNC; external 'basswma.dll';
(* Setup a sync on a WMA channel. Multiple syncs may be used per channel.
handle : Channel handle
atype  : Sync type (BASS_SYNC_xxx type & flags)
param  : Sync parameters (see the BASS_SYNC_xxx type description)
proc   : User defined callback function
user   : The 'user' value passed to the callback function
RETURN : Sync handle (NULL=error) *)

function BASS_WMA_ChannelRemoveSync conv arg_stdcall (handle:DWORD; sync:HSYNC): BOOL; external 'basswma.dll';
(* Remove a sync from a WMA channel
handle : Channel handle
sync   : Handle of sync to remove *)

function BASS_WMA_GetIWMReader conv arg_stdcall (handle: DWORD): Pointer; external 'basswma.dll';
(* Retrieve the IWMReader interface of a WMA stream. This allows direct
access to the WMFSDK functions.
handle : Channel handle
RETURN : Pointer to the IWMReader object interface (NULL=error) *)


Function BASS_WMA_EncodeGetRates conv arg_stdcall (freq,flags:DWORD): Pointer; external 'basswma.dll';
{
  Retrieve a list of the encoding bitrates available for a
  specified input sample format.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO flag
  RETURN : Pointer to an array of bitrates, terminated by a 0 (NULL=error)
}
Function BASS_WMA_EncodeOpenFile conv arg_stdcall (freq,flags,bitrate:DWORD; fname:PChar): HWMENCODE; external 'basswma.dll';
{
  Initialize WMA encoding to a file.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
  bitrate: Encoding bitrate
  fname  : Filename
  RETURN : The created encoder's handle (0=error)
}
Function BASS_WMA_EncodeOpenNetwork conv arg_stdcall (freq,flags,bitrate,port,clients:DWORD): HWMENCODE; external 'basswma.dll';
{
  Initialize WMA encoding to the network.
  freq   : Sampling rate
  flags  : BASS_SAMPLE_MONO/BASS_WMA_ENCODE_TAGS flags
  bitrate: Encoding bitrate
  port   : Port number for clients to conenct to (0=let system choose)
  clients: Maximum number of clients that can connect
  RETURN : The created encoder's handle (0=error)
}
Function BASS_WMA_EncodeGetPort conv arg_stdcall (handle:HWMENCODE): DWORD; external 'basswma.dll';
{
  Retrieve the port for clients to connect to a network encoder.
  handle : Encoder handle
  RETURN : The port number for clients to connect to (0=error)
}
Function BASS_WMA_EncodeGetClients conv arg_stdcall (handle:HWMENCODE): DWORD; external 'basswma.dll';
{
  Retrieve the number of clients connected.
  handle : Encoder handle
  RETURN : The number of clients (-1=error)
}
Function BASS_WMA_EncodeSetTag conv arg_stdcall (handle:HWMENCODE; tag,text:PChar): BOOL; external 'basswma.dll';
{
  Set a tag. Requires that the BASS_WMA_ENCODE_TAGS flag was used in
  the BASS_WMA_EncodeOpenFile/Network call. 
  handle : Encoder handle
  tag    : The tag (NULL=no more tags)
  text   : The tag's text
}
Function BASS_WMA_EncodeWrite conv arg_stdcall (handle:HWMENCODE; buffer:Pointer; length:DWORD): BOOL; external 'basswma.dll';
{
  Encode sample data and write it to the file or network.
  handle : Encoder handle
  buffer : Buffer containing the sample data
  length : Number of bytes in the buffer
}
Procedure BASS_WMA_EncodeClose conv arg_stdcall (handle:HWMENCODE); external 'basswma.dll';
{
  Finish encoding and close the file or network port.
  handle : Encoder handle
}

implementation
  (* nothing to implement *)
end.