(* WMA version of the BASS Console WAVE Writer, copyright (c) 2002 Ian Luck.
TMT Pascal version by Vadim Bodrov, TMT Development Corp. (support@tmt.com)
============================================================================
Imports: bass.lib, basswma.lib, kernel32.lib
*)

uses Strings, Windows, MMSystem, Bass, BassWMA, Keyboard;

function IntToFixed(val, digits: Longint): string;
var
  s: string;
begin
  s := IntToStr(val);
  while Length(s) < digits do s := '0' + s;
  Result := s;
end;

// display error messages
procedure Error(text: string);
begin
  WriteLn('Error(' + IntToStr(BASS_ErrorGetCode) + '): ' + text);
  BASS_Free;
  Halt(0);
end;

var
        buf: PChar;
        chan, pos, flags: DWORD;
        str: BOOL := FALSE;
        fp: File;
        wf: TWAVEFORMATEX;
begin
        Writeln('BASS WAVE writer example : MOD/MPx/OGG/WMA -> BASS.WAV');
        Writeln('------------------------------------------------------');

        (* check that BASS 1.6 was loaded *)
        if BASS_GetVersion <> MAKELONG(1,6) then
        begin
                Writeln('BASS version 1.6 was not loaded');
                exit;
        end;

        if ParamCount <> 1 then
        begin
                Writeln(#9 + 'usage: writeraw <file>');
                exit;
        end;

        GetMem(buf, 10000);

        (* setup output - "no sound" device, 44100hz, stereo, 16 bits *)
        if not BASS_Init(-2, 44100, BASS_DEVICE_NOTHREAD, 0) then
                Error('Can''t initialize device');
        (* try streaming the file/url *)
        StrPCopy(buf, ParamStr(1));
        chan := BASS_StreamCreateFile(FALSE, buf, 0, 0, BASS_STREAM_DECODE);
        if chan = 0 then
                chan := BASS_StreamCreateURL(buf, 0, BASS_STREAM_DECODE, nil);
        if chan = 0 then
                chan := BASS_WMA_StreamCreateFile(FALSE, buf, 0, 0, BASS_STREAM_DECODE);
        if chan <> 0 then
        begin
                if BASS_WMA_GetIWMReader(chan) <> nil then // it's a WMA channel?
                        pos := BASS_WMA_StreamGetLength(chan)
                else
                        pos := BASS_StreamGetLength(chan);
                Write('streaming file [', pos, ' bytes]');
                str := TRUE;
        end else
        begin
                (* try loading the MOD (with sensitive ramping, surround sound and calculate the duration) *)
                chan := BASS_MusicLoad(FALSE, buf, 0, 0, BASS_MUSIC_DECODE or BASS_MUSIC_RAMPS or BASS_MUSIC_SURROUND or BASS_MUSIC_CALCLEN or BASS_MUSIC_LOOP);
                if chan = 0 then
                        (* not a MOD either *)
                        Error('Can''t play the file');
                Write('playing MOD music "', BASS_MusicGetName(chan), '" [', BASS_MusicGetLength(chan, FALSE), ' orders]');
                pos := BASS_MusicGetLength(chan, TRUE);
        end;

        (* display the time length *)
        if pos <> 0 then
        begin
                time := Trunc(BASS_ChannelBytes2Seconds(chan, pos));
                Writeln(' ', time div 60, ':', time mod 60);
        end else (* no time length available *)
                Writeln;

        Assign(fp, 'BASS.WAV');
{$I-}
        Rewrite(fp, 1);
{$I+}
        if IOResult <> 0 then Error('Can''t create file');
        Writeln('writing to BASS.WAV file... press a key to stop');

        (* write WAV header *)
        flags := BASS_ChannelGetFlags(chan);
        wf.wFormatTag := 1;
        if (flags and BASS_SAMPLE_MONO) <> 0 then
          wf.nChannels := 1
        else
          wf.nChannels := 2;
        if (flags and BASS_SAMPLE_8BITS) <> 0 then
          wf.wBitsPerSample := 8
        else
          wf.wBitsPerSample := 16;
        wf.nBlockAlign := wf.nChannels * wf.wBitsPerSample div 8;
        declare var pan: Longint; volume: DWORD;
        BASS_ChannelGetAttributes(chan, wf.nSamplesPerSec, volume, pan);
        wf.nAvgBytesPerSec := wf.nSamplesPerSec * wf.nBlockAlign;

        StrPCopy(buf, 'RIFF'+#0+#0+#0+#0+'WAVEfmt '+#16+#0+#0+#0);
        BlockWrite(fp, buf^, 20);
        BlockWrite(fp, wf, 16);
        StrPCopy(buf, 'data'+#0+#0+#0+#0);
        BlockWrite(fp, buf^, 8);

        while (not KbHit) and (BASS_ChannelIsActive(chan) <> 0) do
        begin
                BlockWrite(fp, buf^, BASS_ChannelGetData(chan, buf, 10000));
                pos := BASS_WMA_ChannelGetPosition(chan);
                if pos = -1 then // not a WMA channel
                        pos := BASS_ChannelGetPosition(chan);
                if str then
                        Write('pos ', IntToFixed(pos, 9), #13)
                else
                        Write('pos ', IntToFixed(LOWORD(pos), 3), ':', IntToFixed(HIWORD(pos), 3), #13);
                Sleep(1); // don't hog the CPU too much :)
        end;

        (* complete WAV header *)
        declare
        var
          tmp: DWORD;
        begin
                pos := FilePos(fp);
                Seek(fp, 4);
                tmp := pos - 8;
                BlockWrite(fp, tmp, 4);
                Seek(fp, 40);
                tmp := pos - 44;
                BlockWrite(fp, tmp, 4);
        end;
        Close(fp);

        BASS_WMA_StreamFree(chan); // incase it's a WMA channel
        BASS_Free;
end.
