Attribute VB_Name = "modWMAlive"
'////////////////////////////////////////////////////////////////
' modWMAlive.BAS - Copyright (c) 2002
'                          JOBnik! [Arthur Aminov, ISRAEL]
'                          e-mail: jobnik2k@hotmail.com
'
' BASS WMA live broadcast example
'
' Originally translated from - wmalive.c - Example of Ian Luck
'
' Uses: API Timer
'////////////////////////////////////////////////////////////////

Public Declare Function SetTimer Lib "user32" (ByVal hWnd As Long, ByVal nIDEvent As Long, ByVal uElapse As Long, ByVal lpTimerFunc As Long) As Long
Public Declare Function KillTimer Lib "user32" (ByVal hWnd As Long, ByVal nIDEvent As Long) As Long

Public Const SAMPLERATE = 44100
Public handle As Long   ' encoder handle
Public time As Single   ' elapsed time
Public level As Long    ' input level

' update the status and level display
Public Sub UpdateDisplay()

    Dim text As String
    text = "Off Air"
    
    If (BASS_ChannelIsActive(RECORDCHAN)) Then
        Dim t As Integer, l As Long
        t = Int(time)
        text = "On Air - port: " & BASS_WMA_EncodeGetPort(handle) & " - " & Int(t / 60) & ":" & Int(t Mod 60)
        l = BASS_ChannelGetLevel(RECORDCHAN) ' get current level
        level = IIf(level > 5, level - 5, 0)
        If (GetLoWord(l) > level) Then level = GetLoWord(l)
        If (GetHiWord(l) > level) Then level = GetHiWord(l)
    Else
        level = 0
    End If
    
    With frmWMAlive
        'draw the level bar
        .picLevelBar.Cls
        .picLevelBar.Line (.picLevelBar.Width, .picLevelBar.Height)-(0, .picLevelBar.Height * (128 - level) / 128), vbWhite, BF:
        
        'update status text
        .lblOffAir.Caption = text
    End With
    
End Sub

' recording callback
Public Function RecordingCallback(ByVal buffer As Long, ByVal length As Long, ByVal user As Long) As Integer
    time = time + (length / (SAMPLERATE * 4)) ' increase elapsed time counter
    'encode the sample data, and continue recording if successful
    RecordingCallback = BASS_WMA_EncodeWrite(handle, buffer, length)
End Function

' start recording & encoding
Public Sub start()
    
    With frmWMAlive
        If .cmbBitrate.ListIndex = -1 Then
            MsgBox "Error: Can't initialize encoding", vbCritical
            Exit Sub
        End If
        
        Dim bitrate As Long
        'get bitrate
        bitrate = Val(.cmbBitrate.List(.cmbBitrate.ListIndex))
        'initialize encoder - let system choose port, max 5 clients
        handle = BASS_WMA_EncodeOpenNetwork(SAMPLERATE, BASS_WMA_ENCODE_TAGS, bitrate, 0, 5)
        If (handle = 0) Then
            MsgBox "Error: Can't initialize encoding", vbCritical
            Exit Sub
        End If
        
        Dim title As String
        'get title
        title = Trim(.txtTitle.text)
        Call BASS_WMA_EncodeSetTag(handle, "Title", title) ' set WMA title tag
        Call BASS_WMA_EncodeSetTag(handle, vbNullString, vbNullString)  ' done setting tags
        time = 0
        'start recording
        If (BASS_RecordStart(SAMPLERATE, 0, AddressOf RecordingCallback, 0) = 0) Then
            MsgBox "Error: Can't start recording", vbCritical
            Call BASS_WMA_EncodeClose(handle)
            Exit Sub
        End If
        
        .btnStart.Caption = "Stop"
        .txtTitle.Enabled = False
        .cmbBitrate.Enabled = False
        Call SetTimer(.hWnd, 0, 50, AddressOf TimerCallback)
    End With
End Sub

'stop recording & encoding
Public Sub Stop_()
    With frmWMAlive
        Call KillTimer(.hWnd, 0)
        Call BASS_ChannelStop(RECORDCHAN)  ' stop recording
        Call BASS_WMA_EncodeClose(handle)  ' stop encoding
        .btnStart.Caption = "Start"
        .txtTitle.Enabled = True
        .cmbBitrate.Enabled = True
        Call UpdateDisplay
    End With
End Sub

'API Timer CALLBACK function
Public Sub TimerCallback(ByVal hWnd As Long, ByVal uMsg As Long, ByVal idEvent As Long, ByVal dwTime As Long)
    If (BASS_ChannelIsActive(RECORDCHAN) = 0) Then
        Call Stop_
    Else
        Call UpdateDisplay
    End If
End Sub
